SUBROUTINE USR_RATES(IJK, RATES)

      USE param
      USE param1
      USE parallel
      USE fldvar
      USE rxns
      USE energy
      USE geometry
      USE run
      USE indices
      USE physprop
      USE constant
      USE funits
      USE compar
      USE sendrecv
      USE toleranc
      USE functions
      USE fun_avg
      USE usr

      IMPLICIT NONE

      INTEGER, INTENT(IN) :: IJK
      
      DOUBLE PRECISION, DIMENSION(NO_OF_RXNS), INTENT(OUT) :: RATES

      INCLUDE 'species.inc'

! Reaction specific variables:
!`````````````````````````````````````````````````````````````````````//
!Reaction_1 {chem_eq = "hdpe --> 40*C2H4 + 40*C3H6"}

!Reaction_2 {chem_eq = "hdpe --> Eicosan"}

!Reaction_3 {chem_eq = "hdpe --> 10*C10H18 + 10*C10H22"}

!Reaction_4 {chem_eq = "Eicosan --> C10H18 + C10H22"}

!Reaction_5 {chem_eq = "Eicosan --> C8H8 + C7H8 + 5*CH4 + 2*H2"}

!Reaction_5 {chem_eq = "C7H8 --> 2*C2H4 + 3*CHAR"}

! Bounded phase temperatures (K)
      DOUBLE PRECISION :: TgX   ! gas phase
      DOUBLE PRECISION :: TsX   ! solids phase 2
      DOUBLE PRECISION :: TgsX  ! Average of gas/solids 2
      
! Molar concentration of reaction species (mol/cm^3)
      DOUBLE PRECISION :: c_hdpe
      DOUBLE PRECISION :: c_Eicosan
      DOUBLE PRECISION :: c_C7H8
	  
! Bound the gas and solids phase temperatures.
      TgX  = min(TMAX, T_g(IJK))
      TsX  = min(TMAX, T_s(IJK,2))

! Compute the gas/solid2 average bounded temperature.
      TgsX = HALF * (TgX + TsX)

! Compute concentration of hdpe (gmole/cm^3)
     c_hdpe = ROP_s(IJK,2)*X_s(IJK,2,hdpe)/MW_s(2,hdpe) 

! Compute concentration of Eicosan (gmole/cm^3)
     c_Eicosan = ROP_g(IJK)*X_g(IJK,Eicosan)/MW_g(Eicosan)
	 
! Compute concentration of C7H8 (gmole/cm^3)
     c_C7H8 = ROP_g(IJK)*X_g(IJK,C7H8)/MW_g(C7H8)
 
      RATES(Reaction_1) = 7.31d6*exp(-137/(8.3145*TgsX))*ROP_s(IJK,2)*X_s(IJK,2,hdpe)/MW_s(2,hdpe)
      RATES(Reaction_2) = 9.77d2*exp(-71.2/(8.3145*TgsX))*ROP_s(IJK,2)*X_s(IJK,2,hdpe)/MW_s(2,hdpe)
      RATES(Reaction_3) = 1.30d3*exp(-84.3/(8.3145*TgsX))*ROP_s(IJK,2)*X_s(IJK,2,hdpe)/MW_s(2,hdpe)
	  RATES(Reaction_4) = 4.72d22*exp(-411/(8.3145*TgsX))*ROP_g(IJK)*X_g(IJK,Eicosan)/MW_g(Eicosan)
      RATES(Reaction_5) = 2.39d21*exp(-391/(8.3145*TgsX))*ROP_g(IJK)*X_g(IJK,Eicosan)/MW_g(Eicosan)
      RATES(Reaction_6) = 2.01d20*exp(-382/(8.3145*TgsX))*ROP_g(IJK)*X_g(IJK,C7H8)/MW_g(C7H8)


RETURN
      
END SUBROUTINE USR_RATES